@@ -169,3 +169,17 @@ void service_ftp(char *ip, int sp, unsigned char options, char *miscptr, FILE *
 void service_ftps(char *ip, int sp, unsigned char options, char *miscptr, FILE * fp, int port) {
   service_ftp_core(ip, sp, options, miscptr, fp, port, 1);
 }
+
+int service_ftp_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
