@@ -46,7 +46,7 @@ int start_telnet(int s, char *ip, int port, unsigned char options, char *miscptr
     }
     (void) make_to_lower(buf);
 
-    if (strstr(buf, "asswor") != NULL || strstr(buf, "asscode") != NULL || strstr(buf, "ennwort") != NULL)
+    if (hydra_strcasestr(buf, "asswor") != NULL || hydra_strcasestr(buf, "asscode") != NULL || hydra_strcasestr(buf, "ennwort") != NULL)
       i = 1;
     if (i == 0 && ((strstr(buf, "ogin:") != NULL && strstr(buf, "last login") == NULL) || strstr(buf, "sername:") != NULL)) {
       free(buf);
@@ -144,7 +144,7 @@ void service_telnet(char *ip, int sp, unsigned char options, char *miscptr, FILE
           hydra_child_exit(2);
         }
       }
-      if (hydra_strcasestr(buf, "login") != NULL || strstr(buf, "username:") != NULL) {
+      if (hydra_strcasestr(buf, "login") != NULL || hydra_strcasestr(buf, "sername:") != NULL) {
         waittime = 6;
         if (debug)
           hydra_report(stdout, "DEBUG: waittime set to %d\n", waittime);
@@ -183,7 +183,7 @@ void service_telnet(char *ip, int sp, unsigned char options, char *miscptr, FILE
         }
         if (buf != NULL && buf[0] != 0 && (unsigned char) buf[0] != IAC)
           make_to_lower(buf);
-      } while (buf != NULL && (unsigned char) buf[0] == IAC && strstr(buf, "ogin:") == NULL && strstr(buf, "sername:") == NULL);
+      } while (buf != NULL && (unsigned char) buf[0] == IAC && hydra_strcasestr(buf, "ogin:") == NULL && hydra_strcasestr(buf, "sername:") == NULL);
       free(buf);
       waittime = old_waittime;
       next_run = 2;
@@ -203,3 +203,17 @@ void service_telnet(char *ip, int sp, unsigned char options, char *miscptr, FILE
     run = next_run;
   }
 }
+
+int service_telnet_init(char *ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
+  // called before the childrens are forked off, so this is the function
+  // which should be filled if initial connections and service setup has to be
+  // performed once only.
+  //
+  // fill if needed.
+  // 
+  // return codes:
+  //   0 all OK
+  //   -1  error, hydra will exit, so print a good error message here
+
+  return 0;
+}
