@@ -133,10 +133,9 @@ void service_vmauthd(char *ip, int sp, unsigned char options, char *miscptr, FIL
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       hydra_child_exit(0);
-      return;
     default:
       hydra_report(stderr, "[ERROR] Caught unknown return code, exiting!\n");
-      hydra_child_exit(0);
+      hydra_child_exit(2);
     }
     run = next_run;
   }
